@@ -6,11 +6,11 @@ from netbox.api.viewsets import NetBoxModelViewSet
 
 from netbox_storage.api.serializers import (
     DriveSerializer,
-    FilesystemSerializer, LinuxVolumeSerializer, LinuxVolumeDriveSerializer,
+    FilesystemSerializer, LinuxVolumeSerializer, PartitionSerializer, PhysicalVolumeSerializer,
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, LinuxVolumeFilter, \
-    LinuxVolumeDriveFilter
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, LinuxVolumeDrive
+    PartitionFilter, PhysicalVolumeFilter
+from netbox_storage.models import Drive, Filesystem, LinuxVolume, Partition, PhysicalVolume
 
 
 class NetboxStorageRootView(APIRootView):
@@ -58,14 +58,26 @@ class LinuxVolumeViewSet(NetBoxModelViewSet):
         return Response(serializer.data)
 
 
-class LinuxVolumeDriveViewSet(NetBoxModelViewSet):
-    queryset = LinuxVolumeDrive.objects.all()
-    serializer_class = LinuxVolumeDriveSerializer
-    filterset_class = LinuxVolumeDriveFilter
+class PartitionViewSet(NetBoxModelViewSet):
+    queryset = Partition.objects.all()
+    serializer_class = PartitionSerializer
+    filterset_class = PartitionFilter
 
     @action(detail=True, methods=["get"])
-    def linuxvolumedrive(self, request, pk=None):
-        linuxvolumedrive = LinuxVolumeDrive.objects.filter(linuxvolumedrive__id=pk)
-        serializer = LinuxVolumeDriveSerializer(linuxvolumedrive, many=True, context={"request": request})
+    def partition(self, request, pk=None):
+        partition = Partition.objects.filter(partition__id=pk)
+        serializer = PartitionSerializer(partition, many=True, context={"request": request})
+        return Response(serializer.data)
+
+
+class PhysicalVolumeViewSet(NetBoxModelViewSet):
+    queryset = PhysicalVolume.objects.all()
+    serializer_class = PhysicalVolumeSerializer
+    filterset_class = PhysicalVolumeFilter
+
+    @action(detail=True, methods=["get"])
+    def physicalvolume(self, request, pk=None):
+        physicalvolume = PhysicalVolume.objects.filter(partition__id=pk)
+        serializer = PhysicalVolumeSerializer(physicalvolume, many=True, context={"request": request})
         return Response(serializer.data)
 
