@@ -29,9 +29,8 @@ class DriveForm(NetBoxModelForm):
     )
     cluster = DynamicModelChoiceField(
         queryset=Cluster.objects.filter(
-            type=ClusterType.objects.filter(name="Storage").first(),
+            type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
         ),
-        required=False,
         query_params={
             'site_id': '$site',
             'group_id': '$cluster_group',
@@ -70,12 +69,10 @@ class DriveFilterForm(NetBoxModelFilterSetForm):
         label="Size (GB)",
     )
     cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.all(),
+        queryset=Cluster.objects.filter(
+            type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        ),
         required=False,
-        query_params={
-            'site_id': '$site',
-            'group_id': '$cluster_group',
-        }
     )
     virtual_machine = DynamicModelChoiceField(
         queryset=VirtualMachine.objects.all(),
