@@ -69,20 +69,42 @@ linuxvolume_menu_item = PluginMenuItem(
 )
 
 
-linuxvolumedrive_menu_item = PluginMenuItem(
-    link="plugins:netbox_storage:linuxvolumedrive_list",
-    link_text="Linux Volume Drive",
+partition_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:partition_list",
+    link_text="Partition",
     permissions=["netbox_storage.disk_view"],
     buttons=(
         PluginMenuButton(
-            "plugins:netbox_storage:linuxvolumedrive_add",
+            "plugins:netbox_storage:partition_add",
             "Add",
             "mdi mdi-plus-thick",
             ButtonColorChoices.GREEN,
             permissions=["netbox_storage.add_disk"],
         ),
         PluginMenuButton(
-            "plugins:netbox_storage:linuxvolumedrive_import",
+            "plugins:netbox_storage:partition_import",
+            "Import",
+            "mdi mdi-upload",
+            ButtonColorChoices.CYAN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+    ),
+)
+
+physicalvolume_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:physicalvolume_list",
+    link_text="Physical Volume",
+    permissions=["netbox_storage.disk_view"],
+    buttons=(
+        PluginMenuButton(
+            "plugins:netbox_storage:physicalvolume_add",
+            "Add",
+            "mdi mdi-plus-thick",
+            ButtonColorChoices.GREEN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+        PluginMenuButton(
+            "plugins:netbox_storage:physicalvolume_import",
             "Import",
             "mdi mdi-upload",
             ButtonColorChoices.CYAN,
@@ -99,7 +121,8 @@ menu = PluginMenu(
             (
                 filesystem_menu_item,
                 linuxvolume_menu_item,
-                linuxvolumedrive_menu_item,
+                partition_menu_item,
+                physicalvolume_menu_item
             ),
         ),
         (
