@@ -1,7 +1,6 @@
 from extras.plugins import PluginTemplateExtension
 
-from netbox_storage.models import Drive, WindowsVolume
-from netbox_storage.tables import RelatedDriveTable
+from netbox_storage.models import Drive, LinuxVolume
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -13,24 +12,22 @@ class RelatedDrives(PluginTemplateExtension):
         drives = Drive.objects.filter(
             virtual_machine=obj
         )
-        drive_table = RelatedDriveTable(
-            data=drives
-        )
-        volumes = WindowsVolume.objects.filter(
-            virtual_machine=obj
-        )
-        exclude_drive_id = []
-        for volume in volumes.all():
-            for drive in volume.drives.all():
-                exclude_drive_id.append(drive.id)
-        unmapped_drives = Drive.objects.filter(
-            virtual_machine=obj
-        ).exclude(id__in=exclude_drive_id).order_by('identifier')
+        # drive_table = RelatedDriveTable(
+        #     data=drives
+        # )
+        volumes = LinuxVolume.objects.all()
+        # exclude_drive_id = []
+        # for volume in volumes.all():
+        #     for drive in volume.drives.all():
+        #         exclude_drive_id.append(drive.id)
+        # unmapped_drives = Drive.objects.filter(
+        #     virtual_machine=obj
+        # ).exclude(id__in=exclude_drive_id).order_by('identifier')
 
-        all_volumes = WindowsVolume.objects.all()
-        display_volume = []
-        for volume in all_volumes:
-            display_volume = volume.drives.all().intersection(drives)
+        # all_volumes = LinuxVolume.objects.all()
+        # display_volume = []
+        # for volume in all_volumes:
+        #     display_volume = volume.drives.all().intersection(drives)
 
         platform = obj.platform
         if platform is not None:
@@ -39,16 +36,16 @@ class RelatedDrives(PluginTemplateExtension):
                     "netbox_storage/volume/windowsvolume_box.html",
                     extra_context={
                         "volumes": volumes,
-                        "unmapped_drives": unmapped_drives,
+                        # "unmapped_drives": unmapped_drives,
                         "type": type(obj.platform),
-                        "display_volume": display_volume
+                        # "display_volume": display_volume
                     },
                 )
             elif platform.name.lower().__contains__('linux'):
                 return self.render(
                     "netbox_storage/volume/linuxvolume_box.html",
                     extra_context={
-                        "related_drives": drive_table,
+                        # "related_drives": drive_table,
                     },
                 )
         else:
